/// <reference types="node" />
import { PathLikeOrReadStream, PdfFormat } from '../common';
import { PageProperties } from '../libre-office';
/**
 * Class representing a PDF engine for various operations such as merging and conversion.
 */
export declare class PDFEngine {
    /**
     * Merges multiple PDF files into a single PDF document.
     *
     * @param {Object} options - Options for the merge operation.
     * @param {PathLikeOrReadStream[]} options.files - An array of PathLikes or ReadStreams to the PDF files to be merged.
     * @returns {Promise<Buffer>} A Promise resolving to the merged PDF content as a Buffer.
     */
    static merge({ files }: {
        files: PathLikeOrReadStream[];
    }): Promise<Buffer>;
    /**
     * Converts various document formats to PDF.
     *
     * @param {Object} options - Options for the conversion operation.
     * @param {PathLikeOrReadStream[]} options.files - An array of PathLikes or ReadStreams to the files to be converted to PDF.
     * @param {PageProperties} [options.properties] - Page properties for the conversion.
     * @param {PdfFormat} [options.pdfFormat] - PDF format options.
     * @param {boolean} [options.pdfUA] - Indicates whether to generate PDF/UA compliant output.
     * @param {boolean} [options.merge] - Indicates whether to merge the resulting PDFs.
     * @returns {Promise<Buffer>} A Promise resolving to the converted PDF content as a Buffer.
     */
    static convert({ files, properties, pdfFormat, pdfUA, merge }: {
        files: PathLikeOrReadStream[];
        properties?: PageProperties;
        pdfFormat?: PdfFormat;
        pdfUA?: boolean;
        merge?: boolean;
    }): Promise<Buffer>;
    /**
     * Generates a PDF file from a buffer and saves it to the "__generated__" directory.
     *
     * @param {string} filename - The filename for the generated PDF.
     * @param {Buffer} buffer - The PDF content as a Buffer.
     * @returns {Promise<void>} A Promise that resolves once the file is generated and saved.
     */
    static generate(filename: string, buffer: Buffer): Promise<void>;
}
